Neural inference library for executing optimized computation sequences.
This library provides functionality to run neural network inference using a sequence of instructions that operate on computation buffers. It supports various operations like dot products, activations, copying, and element-wise operations.
Re-exports
pub use activation::Activation;pub use instruction_model::InstructionModel;pub use instruction_model_info::InstructionModelInfo;pub use instruction_model_info::ValidationData;pub use parallel_predict::ParallelPredictOutput;pub use parallel_predict::PredictConfig;
Modules
- activation
- Activation functions for neural network operations.
- benchmarks
- Benchmark suite for neural inference performance testing.
- errors
- Error types for the neural inference library.
- gpu
- GPU neural network inference module.
- high_
performance_ execution_ utils - Execution graph structures for parallel instruction execution.
- instruction_
model - Core instruction model for neural network inference.
- instruction_
model_ info - Data structures for instruction model configuration.
- instructions
- Instruction implementations for neural network operations.
- parallel_
predict - utils
- Utility functions for the neural inference library.